Modifications
=============

The modifications modules provide lookups for post-translational modifications from various databases.

Unimod
------

.. automodule:: tacular.unimod.lookup
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: tacular.unimod.dclass
   :members:
   :undoc-members:
   :show-inheritance:

PSI-MOD
-------

.. automodule:: tacular.psimod.lookup
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: tacular.psimod.dclass
   :members:
   :undoc-members:
   :show-inheritance:

RESID
-----

.. automodule:: tacular.resid.lookup
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: tacular.resid.dclass
   :members:
   :undoc-members:
   :show-inheritance:

XLMOD
-----

.. automodule:: tacular.xlmod.lookup
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: tacular.xlmod.dclass
   :members:
   :undoc-members:
   :show-inheritance:

GNOme
-----

.. automodule:: tacular.gno.lookup
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: tacular.gno.dclass
   :members:
   :undoc-members:
   :show-inheritance:
